==> beast_0.3.3.orig.tar.gz: beast-0.3.3/bse/bse.h <==
/* BSE - Bedevilled Sound Engine
 * Copyright (C) 1998, 1999 Olaf Hoehmann and Tim Janik
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 * bse.h: global include file for libbse
 */
#ifndef __BSE_H__
#define __BSE_H__


#include        <glib.h>
#include        <bse/glib-extra.h>

/* BSE includes
 */
#include        <bse/bseglobals.h>
#include        <bse/bsebindata.h>
#include        <bse/bsecategories.h>
#include        <bse/bsechunk.h>
#include        <bse/bseconfig.h>
#include        <bse/bsecontainer.h>
#include        <bse/bsedefs.h>
#include        <bse/bsedevice.h>
#include        <bse/bseeffect.h>
#include        <bse/bseeffectfinetune.h>
#include        <bse/bseeffectnotevolume.h>
#include        <bse/bseeffectpatternbreak.h>
#include        <bse/bseeffectpatternjump.h>
#include        <bse/bseeffectvolumedelta.h>
#include        <bse/bseenums.h>
#include        <bse/bseexports.h>
#include        <bse/bsegconfig.h>
#include        <bse/bseglobals.h>
#include        <bse/bseheart.h>
#include        <bse/bseinstrument.h>
#include        <bse/bseitem.h>
#include        <bse/bsemagic.h>
#include        <bse/bsemain.h>
#include        <bse/bsehunkmixer.h>
#include        <bse/bseobject.h>
#include        <bse/bseparam.h>
#include        <bse/bseparasite.h>
#include        <bse/bsepattern.h>
#include        <bse/bsepatterngroup.h>
#include        <bse/bsepcmdevice.h>
#include        <bse/bseplugin.h>
#include        <bse/bseprocedure.h>
#include        <bse/bseproject.h>
#include        <bse/bsesample.h>
#include        <bse/bsesnet.h>
#include        <bse/bsesong.h>
#include        <bse/bsesource.h>
#include	<bse/bsestorage.h>
#include        <bse/bsesuper.h>
#include        <bse/bsetype.h>
#include        <bse/bseutils.h>
/* #include        <bse/bsevoice.h> */


#endif /* __BSE_H__ */

==> beast-0.4.1-rc1.tar.gz: beast-0.4.1-rc1/bse/bse.h <==
/* BSE - Bedevilled Sound Engine
 * Copyright (C) 1998, 1999 Olaf Hoehmann and Tim Janik
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 * bse.h: global include file for libbse
 */
#ifndef __BSE_H__
#define __BSE_H__


/* BSE includes
 */
#include        <bse/bseglobals.h>
#include        <bse/bsebindata.h>
#include        <bse/bsecategories.h>
#include        <bse/bsecomwire.h>
#include        <bse/bseconfig.h>
#include        <bse/bsecontainer.h>
#include        <bse/bsedatapocket.h>
#include        <bse/bsedefs.h>
#include        <bse/bseeditablesample.h>
#include        <bse/bseenums.h>
#include        <bse/bseexports.h>
#include        <bse/bsegconfig.h>
#include        <bse/bseglobals.h>
#include        <bse/bseitem.h>
#include        <bse/bsemain.h>
#include        <bse/bsemath.h>
#include	<bse/bsemidinotifier.h>
#include	<bse/bsemidisynth.h>
#include        <bse/bseobject.h>
#include        <bse/bseparam.h>
#include        <bse/bseparasite.h>
#include        <bse/bsepart.h>
#include        <bse/bsepcmdevice.h>
#include        <bse/bseplugin.h>
#include        <bse/bseprocedure.h>
#include        <bse/bseproject.h>
#include        <bse/bseserver.h>
#include        <bse/bsescripthelper.h>
#include        <bse/bsescriptcontrol.h>
#include        <bse/bsesnet.h>
#include        <bse/bsesong.h>
#include        <bse/bsesource.h>
#include	<bse/bsestorage.h>
#include        <bse/bsesuper.h>
#include        <bse/bsetrack.h>
#include        <bse/bsetype.h>
#include        <bse/bseutils.h>
#include        <bse/bsewave.h>
#include        <bse/bsewaveosc.h>
#include        <bse/bsewaverepo.h>
#include        <bse/bswcommon.h>


#endif /* __BSE_H__ */
